@@ -45,8 +45,12 @@ for signed numbers like <code>[FixedI32]\<[U32]></code>, and in the range
 <code>[FixedU32]\<[U32]></code>.
 
 In version 1 the [*typenum* crate] is used for the fractional bit count `Frac`;
-the plan is to to have a major version 2 with [const generics] instead when the
-Rust compiler support for them is powerful enough.
+the plan is to to have a major version 2 with const generics when the Rust
+compiler’s [`generic_const_expr` feature] is ready and stabilized. An [alpha
+version] is already available.
+
+[`generic_const_expr` feature]: https://github.com/rust-lang/rust/issues/76560
+[alpha version]: https://crates.io/crates/fixed/2.0.0-alpha.2
 
 The main features are
 
@@ -181,7 +185,7 @@ crate, add it as a dependency inside [*Cargo.toml*]:
 
 ```toml
 [dependencies]
-fixed = "1.12"
+fixed = "1.15"
 ```
 
 The *fixed* crate requires rustc version 1.57.0 or later.
@@ -208,7 +212,7 @@ To enable features, you can add the dependency like this to [*Cargo.toml*]:
 
 ```toml
 [dependencies.fixed]
-version = "1.12"
+version = "1.15"
 features = ["serde"]
 ```
 
@@ -228,7 +232,7 @@ updated to an incompatible newer version.
 
 ## Deprecated optional features
 
-The following optional features are deprecated and may be removed in the next
+The following optional features are deprecated and will be removed in the next
 major version of the crate.
 
  1. `az`, has no effect. Previously required for the [`az`] cast traits. Now
@@ -292,15 +296,13 @@ shall be dual licensed as above, without any additional terms or conditions.
 [`from_str_hex`]: FixedI32::from_str_hex
 [`from_str_octal`]: FixedI32::from_str_octal
 [`to_num`]: FixedI32::to_num
-[const generics]: https://github.com/rust-lang/rust/issues/44580
 */
 #![cfg_attr(not(feature = "std"), no_std)]
 #![warn(missing_docs)]
 #![warn(unsafe_op_in_unsafe_fn)]
-#![doc(html_root_url = "https://docs.rs/fixed/~1.12")]
+#![doc(html_root_url = "https://docs.rs/fixed/~1.15")]
 #![doc(test(attr(deny(warnings))))]
 #![cfg_attr(feature = "fail-on-warnings", deny(warnings))]
-#![allow(clippy::question_mark)]
 
 #[cfg(all(not(feature = "std"), test))]
 extern crate std;
@@ -334,6 +336,7 @@ mod prim_traits;
 #[cfg(feature = "serde")]
 mod serdeize;
 pub mod traits;
+mod traits_bits;
 pub mod types;
 mod unwrapped;
 mod wrapping;
@@ -342,7 +345,6 @@ mod wrapping;
 pub use crate::impl_num_traits::RadixParseFixedError;
 use crate::{
     from_str::FromStrRadix,
-    log10::IntFracLog10,
     traits::{FromFixed, ToFixed},
     types::extra::{
         Diff, IsLessOrEqual, LeEqU128, LeEqU16, LeEqU32, LeEqU64, LeEqU8, Sum, True, Unsigned, U12,
@@ -408,36 +410,41 @@ macro_rules! fixed {
     (
         $description:expr,
         $Fixed:ident(
-            $Inner:ident, $LeEqU:tt, $UNbits:ident, $s_nbits:expr,
-            $s_nbits_m1:expr, $s_nbits_m2:expr, $s_nbits_m3:expr, $s_nbits_m4:expr
+            $Inner:ident, $LeEqU:tt, $UNbits:ident, $UNbits_m1:ident, $s_nbits:expr,
+            $s_nbits_p1:expr, $s_nbits_m1:expr, $s_nbits_m2:expr, $s_nbits_m3:expr, $s_nbits_m4:expr
         ),
         $nbytes:expr, $bytes_val:expr, $rev_bytes_val:expr, $be_bytes:expr, $le_bytes:expr,
-        $UFixed:ident, $UInner:ty, $Signedness:tt,
+        $IFixed:ident, $UFixed:ident, $IInner:ident, $UInner:ident, $Signedness:tt,
         $LeEqU_C0:tt, $LeEqU_C1:tt, $LeEqU_C2:tt, $LeEqU_C3:tt,
-        $HasDouble:tt, $Double:ident, $DoubleInner:ty, $s_nbits_2:expr
+        $HasDouble:tt, $s_nbits_2:expr,
+        $Double:ident, $DoubleInner:ty, $IDouble:ident, $IDoubleInner:ty
     ) => {
         fixed! {
             $description,
             $Fixed[stringify!($Fixed)](
-                $Inner[stringify!($Inner)], $LeEqU, $UNbits, $s_nbits,
-                $s_nbits_m1, $s_nbits_m2, $s_nbits_m3, $s_nbits_m4
+                $Inner[stringify!($Inner)], $LeEqU, $UNbits, $UNbits_m1, $s_nbits,
+                $s_nbits_p1, $s_nbits_m1, $s_nbits_m2, $s_nbits_m3, $s_nbits_m4
             ),
             $nbytes, $bytes_val, $rev_bytes_val, $be_bytes, $le_bytes,
-            $UFixed[stringify!($UFixed)], $UInner, $Signedness,
+            $IFixed[stringify!($IFixed)], $UFixed[stringify!($UFixed)],
+            $IInner, $UInner, $Signedness,
             $LeEqU_C0, $LeEqU_C1, $LeEqU_C2, $LeEqU_C3,
-            $HasDouble, $Double[stringify!($Double)], $DoubleInner, $s_nbits_2
+            $HasDouble, $s_nbits_2,
+            $Double[stringify!($Double)], $DoubleInner, $IDouble, $IDoubleInner
         }
     };
     (
         $description:expr,
         $Fixed:ident[$s_fixed:expr](
-            $Inner:ident[$s_inner:expr], $LeEqU:tt, $UNbits:ident, $s_nbits:expr,
-            $s_nbits_m1:expr, $s_nbits_m2:expr, $s_nbits_m3:expr, $s_nbits_m4:expr
+            $Inner:ident[$s_inner:expr], $LeEqU:tt, $UNbits:ident, $UNbits_m1:ident, $s_nbits:expr,
+            $s_nbits_p1:expr, $s_nbits_m1:expr, $s_nbits_m2:expr, $s_nbits_m3:expr, $s_nbits_m4:expr
         ),
         $nbytes:expr, $bytes_val:expr, $rev_bytes_val:expr, $be_bytes:expr, $le_bytes:expr,
-        $UFixed:ident[$s_ufixed:expr], $UInner:ty, $Signedness:tt,
+        $IFixed:ident[$s_ifixed:expr], $UFixed:ident[$s_ufixed:expr],
+        $IInner:ident, $UInner:ident, $Signedness:tt,
         $LeEqU_C0:tt, $LeEqU_C1:tt, $LeEqU_C2:tt, $LeEqU_C3:tt,
-        $HasDouble:tt, $Double:ident[$s_double:expr], $DoubleInner:ty, $s_nbits_2:expr
+        $HasDouble:tt, $s_nbits_2:expr,
+        $Double:ident[$s_double:expr], $DoubleInner:ty, $IDouble:ident, $IDoubleInner:ty
     ) => {
         comment! {
             $description, "-bit ",
@@ -480,8 +487,9 @@ range ",
             ".
 
 `Frac` is an [`Unsigned`] as provided by the [*typenum* crate]; the plan is to
-to have a major version 2 with [const generics] instead when the Rust compiler
-support for them is powerful enough.
+to have a major version 2 where `Frac` is replaced by `FRAC` of type [`i32`]
+when the Rust compiler’s [`generic_const_expr` feature] is ready and stabilized.
+An [alpha version] is already available.
 
 `", $s_fixed, "<Frac>` has the same size, alignment and ABI as [`", $s_inner, "`];
 it is `#[repr(transparent)]` with [`", $s_inner, "`] as the only non-zero-sized field.
@@ -501,9 +509,10 @@ assert_eq!(two_point_75.to_string(), \"2.8\");
 ```
 
 [*typenum* crate]: https://crates.io/crates/typenum
-[U0]: crate::types::extra::U0
 [U", $s_nbits, "]: crate::types::extra::U", $s_nbits, "
-[const generics]: https://github.com/rust-lang/rust/issues/44580
+[U0]: crate::types::extra::U0
+[`generic_const_expr` feature]: https://github.com/rust-lang/rust/issues/76560
+[alpha version]: https://crates.io/crates/fixed/2.0.0-alpha.2
 ";
             #[repr(transparent)]
             pub struct $Fixed<Frac> {
@@ -543,10 +552,15 @@ assert_eq!(two_point_75.to_string(), \"2.8\");
 
         // inherent methods that do not require Frac bounds, some of which can thus be const
         fixed_no_frac! {
-            $Fixed[$s_fixed]($Inner[$s_inner], $LeEqU, $UNbits, $s_nbits, $s_nbits_m1, $s_nbits_m2),
+            $Fixed[$s_fixed](
+                $Inner[$s_inner], $LeEqU, $UNbits, $UNbits_m1,
+                $s_nbits, $s_nbits_p1, $s_nbits_m1, $s_nbits_m2, $s_nbits_m3
+            ),
             $nbytes, $bytes_val, $rev_bytes_val, $be_bytes, $le_bytes,
-            $UFixed[$s_ufixed], $UInner, $Signedness,
-            $HasDouble, $Double[$s_double], $DoubleInner, $s_nbits_2
+            $IFixed[$s_ifixed], $UFixed[$s_ufixed],
+            $IInner, $UInner, $Signedness,
+            $HasDouble, $s_nbits_2,
+            $Double[$s_double], $DoubleInner, $IDouble, $IDoubleInner
         }
         // inherent methods that require Frac bounds, and cannot be const
         fixed_frac! {
@@ -563,97 +577,97 @@ assert_eq!(two_point_75.to_string(), \"2.8\");
 
 fixed! {
     "An eight",
-    FixedU8(u8, LeEqU8, U8, "8", "7", "6", "5", "4"),
+    FixedU8(u8, LeEqU8, U8, U7, "8", "9", "7", "6", "5", "4"),
     1, "0x12", "0x12", "[0x12]", "[0x12]",
-    FixedU8, u8, Unsigned,
+    FixedI8, FixedU8, i8, u8, Unsigned,
     U8, U7, U6, U5,
-    True, FixedU16, u16, "16"
+    True, "16", FixedU16, u16, FixedI16, i16
 }
 fixed! {
     "A 16",
-    FixedU16(u16, LeEqU16, U16, "16", "15", "14", "13", "12"),
+    FixedU16(u16, LeEqU16, U16, U15, "16", "17", "15", "14", "13", "12"),
     2, "0x1234", "0x3412", "[0x12, 0x34]", "[0x34, 0x12]",
-    FixedU16, u16, Unsigned,
+    FixedI16, FixedU16, i16, u16, Unsigned,
     U16, U15, U14, U13,
-    True, FixedU32, u32, "32"
+    True, "32", FixedU32, u32, FixedI32, i32
 }
 fixed! {
     "A 32",
-    FixedU32(u32, LeEqU32, U32, "32", "31", "30", "29", "28"),
+    FixedU32(u32, LeEqU32, U32, U31, "32", "33", "31", "30", "29", "28"),
     4, "0x1234_5678", "0x7856_3412", "[0x12, 0x34, 0x56, 0x78]", "[0x78, 0x56, 0x34, 0x12]",
-    FixedU32, u32, Unsigned,
+    FixedI32, FixedU32, i32, u32, Unsigned,
     U32, U31, U30, U29,
-    True, FixedU64, u64, "64"
+    True, "64", FixedU64, u64, FixedI64, i64
 }
 fixed! {
     "A 64",
-    FixedU64(u64, LeEqU64, U64, "64", "63", "62", "61", "60"),
+    FixedU64(u64, LeEqU64, U64, U63, "64", "65", "63", "62", "61", "60"),
     8, "0x1234_5678_9ABC_DE0F", "0x0FDE_BC9A_7856_3412",
     "[0x12, 0x34, 0x56, 0x78, 0x9A, 0xBC, 0xDE, 0x0F]",
     "[0x0F, 0xDE, 0xBC, 0x9A, 0x78, 0x56, 0x34, 0x12]",
-    FixedU64, u64, Unsigned,
+    FixedI64, FixedU64, i64, u64, Unsigned,
     U64, U63, U62, U61,
-    True, FixedU128, u128, "128"
+    True, "128", FixedU128, u128, FixedI128, i128
 }
 fixed! {
     "A 128",
-    FixedU128(u128, LeEqU128, U128, "128", "127", "126", "125", "124"),
+    FixedU128(u128, LeEqU128, U128, U127, "128", "129", "127", "126", "125", "124"),
     16, "0x1234_5678_9ABC_DEF0_0102_0304_0506_0708",
     "0x0807_0605_0403_0201_F0DE_BC9A_7856_3412",
     "[0x12, 0x34, 0x56, 0x78, 0x9A, 0xBC, 0xDE, 0xF0, \
      0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08]",
     "[0x08, 0x07, 0x06, 0x05, 0x04, 0x03, 0x02, 0x01, \
      0xF0, 0xDE, 0xBC, 0x9A, 0x78, 0x56, 0x34, 0x12]",
-    FixedU128, u128, Unsigned,
+    FixedI128, FixedU128, i128, u128, Unsigned,
     U128, U127, U126, U125,
-    False, FixedU128, u128, "128"
+    False, "128", FixedU128, u128, FixedI128, i128
 }
 fixed! {
     "An eight",
-    FixedI8(i8, LeEqU8, U8, "8", "7", "6", "5", "4"),
+    FixedI8(i8, LeEqU8, U8, U7, "8", "9", "7", "6", "5", "4"),
     1, "0x12", "0x12", "[0x12]", "[0x12]",
-    FixedU8, u8, Signed,
+    FixedI8, FixedU8, i8, u8, Signed,
     U7, U6, U5, U4,
-    True, FixedI16, i16, "16"
+    True, "16", FixedI16, i16, FixedI16, i16
 }
 fixed! {
     "A 16",
-    FixedI16(i16, LeEqU16, U16,"16", "15", "14", "13", "12"),
+    FixedI16(i16, LeEqU16, U16, U15, "16", "17", "15", "14", "13", "12"),
     2, "0x1234", "0x3412", "[0x12, 0x34]", "[0x34, 0x12]",
-    FixedU16, u16, Signed,
+    FixedI16, FixedU16, i16, u16, Signed,
     U15, U14, U13, U12,
-    True, FixedI32, i32, "32"
+    True, "32", FixedI32, i32, FixedI32, i32
 }
 fixed! {
     "A 32",
-    FixedI32(i32, LeEqU32, U32, "32", "31", "30", "29", "28"),
+    FixedI32(i32, LeEqU32, U32, U31, "32", "33", "31", "30", "29", "28"),
     4, "0x1234_5678", "0x7856_3412", "[0x12, 0x34, 0x56, 0x78]", "[0x78, 0x56, 0x34, 0x12]",
-    FixedU32, u32, Signed,
+    FixedI32, FixedU32, i32, u32, Signed,
     U31, U30, U29, U28,
-    True, FixedI64, i64, "64"
+    True, "64", FixedI64, i64, FixedI64, i64
 }
 fixed! {
     "A 64",
-    FixedI64(i64, LeEqU64, U64, "64", "63", "62", "61", "60"),
+    FixedI64(i64, LeEqU64, U64, U63, "64", "65", "63", "62", "61", "60"),
     8, "0x1234_5678_9ABC_DE0F", "0x0FDE_BC9A_7856_3412",
     "[0x12, 0x34, 0x56, 0x78, 0x9A, 0xBC, 0xDE, 0x0F]",
     "[0x0F, 0xDE, 0xBC, 0x9A, 0x78, 0x56, 0x34, 0x12]",
-    FixedU64, u64, Signed,
+    FixedI64, FixedU64, i64, u64, Signed,
     U63, U62, U61, U60,
-    True, FixedI128, i128, "128"
+    True, "128", FixedI128, i128, FixedI128, i128
 }
 fixed! {
     "A 128",
-    FixedI128(i128, LeEqU128, U128, "128", "127", "126", "125", "124"),
+    FixedI128(i128, LeEqU128, U128, U127, "128", "129", "127", "126", "125", "124"),
     16, "0x1234_5678_9ABC_DEF0_0102_0304_0506_0708",
     "0x0807_0605_0403_0201_F0DE_BC9A_7856_3412",
     "[0x12, 0x34, 0x56, 0x78, 0x9A, 0xBC, 0xDE, 0xF0, \
      0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08]",
     "[0x08, 0x07, 0x06, 0x05, 0x04, 0x03, 0x02, 0x01, \
      0xF0, 0xDE, 0xBC, 0x9A, 0x78, 0x56, 0x34, 0x12]",
-    FixedU128, u128, Signed,
+    FixedI128, FixedU128, i128, u128, Signed,
     U127, U126, U125, U124,
-    False, FixedI128, i128, "128"
+    False, "128", FixedI128, i128, FixedI128, i128
 }
 
 /// The bit representation of a *binary128* floating-point number (`f128`).
@@ -757,8 +771,8 @@ impl F128Bits {
 /// [`from_num`]: FixedI32::from_num
 #[macro_export]
 macro_rules! const_fixed_from_int {
-    ($(const $NAME:ident: $Fixed:ty = $int:expr;)*) => { $(
-        const $NAME: $Fixed = <$Fixed>::from_bits({
+    ($($vis:vis const $NAME:ident: $Fixed:ty = $int:expr;)*) => { $(
+        $vis const $NAME: $Fixed = <$Fixed>::from_bits({
             // Coerce type.
             let int = <$Fixed>::from_bits($int).to_bits();
             // Divide shift into two parts for cases where $Fixed cannot represent 1.
@@ -794,6 +808,15 @@ macro_rules! const_fixed_from_int {
 ///     const MINUS_TWO_I0: I2F30 = -2;
 ///     const MINUS_TWO_I1: I32F0 = -2;
 /// }
+///
+/// mod test_pub {
+///     use fixed::{const_fixed_from_int, types::*};
+///
+///     const_fixed_from_int! {
+///         pub const PUB: I32F0 = 0;
+///     }
+/// }
+///
 /// assert_eq!(ZERO_I0, 0);
 /// assert_eq!(ZERO_I1, 0);
 /// assert_eq!(ZERO_U0, 0);
@@ -809,6 +832,8 @@ macro_rules! const_fixed_from_int {
 ///
 /// assert_eq!(MINUS_TWO_I0, -2);
 /// assert_eq!(MINUS_TWO_I1, -2);
+///
+/// assert_eq!(test_pub::PUB, 0);
 /// ```
 ///
 /// The rest of the tests should all fail compilation.
@@ -1418,4 +1443,133 @@ mod tests {
             (I1F31::from_num(-1), false)
         );
     }
+
+    #[test]
+    fn wide_mul_mixed() {
+        // +7FFF.FFFF * 7FFF.FFFF = +3FFF_FFFE.0000_0001
+        // 7FFF.FFFF * 7FFF.FFFF = 3FFF_FFFE.0000_0001
+        // +7FFF.FFFF * +7FFF.FFFF = +3FFF_FFFE.0000_0001
+        let s = I16F16::MAX;
+        let u = U16F16::MAX >> 1u32;
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), 0x3FFF_FFFF_0000_0001);
+        assert_eq!(t.wide_mul(u).to_bits(), 0x3FFF_FFFF_0000_0001);
+        assert_eq!(s.wide_mul(v).to_bits(), 0x3FFF_FFFF_0000_0001);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+
+        // +7FFF.FFFF * 8000.0000 = +3FFF_FFFF.8000_0000
+        // 7FFF.FFFF * 8000.0000 = 3FFF_FFFF.8000_0000
+        // +7FFF.FFFF * -8000.0000 = -3FFF_FFFF.8000_0000
+        let s = I16F16::MAX;
+        let u = !(U16F16::MAX >> 1u32);
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), 0x3FFF_FFFF_8000_0000);
+        assert_eq!(t.wide_mul(u).to_bits(), 0x3FFF_FFFF_8000_0000);
+        assert_eq!(s.wide_mul(v).to_bits(), -0x3FFF_FFFF_8000_0000);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+
+        // +7FFF.FFFF * FFFF.FFFF = +7FFF_FFFE.8000_0001
+        // 7FFF.FFFF * FFFF.FFFF = 7FFF_FFFE.8000_0001
+        // +7FFF.FFFF * -0000.0001 = -0000_0000.7FFF_FFFF
+        let s = I16F16::MAX;
+        let u = U16F16::MAX;
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), 0x7FFF_FFFE_8000_0001);
+        assert_eq!(t.wide_mul(u).to_bits(), 0x7FFF_FFFE_8000_0001);
+        assert_eq!(s.wide_mul(v).to_bits(), -0x0000_0000_7FFF_FFFF);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+
+        // -8000.0000 * 7FFF.FFFF = -3FFF_FFFF.8000_0000
+        // 8000.0000 * 7FFF.FFFF = 3FFF_FFFF.8000_0000
+        // -8000.0000 * +7FFF.FFFF = -3FFF_FFFF.8000_0000
+        let s = I16F16::MIN;
+        let u = U16F16::MAX >> 1u32;
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), -0x3FFF_FFFF_8000_0000);
+        assert_eq!(t.wide_mul(u).to_bits(), 0x3FFF_FFFF_8000_0000);
+        assert_eq!(s.wide_mul(v).to_bits(), -0x3FFF_FFFF_8000_0000);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+
+        // -8000.0000 * 8000.0000 = -4000_0000.0000_0000
+        // 8000.0000 * 8000.0000 = 4000_0000.0000_0000
+        // -8000.0000 * -8000.0000 = +4000_0000.0000_0000
+        let s = I16F16::MIN;
+        let u = !(U16F16::MAX >> 1u32);
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), -0x4000_0000_0000_0000);
+        assert_eq!(t.wide_mul(u).to_bits(), 0x4000_0000_0000_0000);
+        assert_eq!(s.wide_mul(v).to_bits(), 0x4000_0000_0000_0000);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+
+        // -8000.0000 * FFFF.FFFF = -7FFF_FFFF.8000_0000
+        // 8000.0000 * FFFF.FFFF = 7FFF_FFFF.8000_0000
+        // -8000.0000 * -0000.0001 = +0000_0000.8000_0000
+        let s = I16F16::MIN;
+        let u = U16F16::MAX;
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), -0x7FFF_FFFF_8000_0000);
+        assert_eq!(t.wide_mul(u).to_bits(), 0x7FFF_FFFF_8000_0000);
+        assert_eq!(s.wide_mul(v).to_bits(), 0x8000_0000);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+
+        // -0000.0001 * 7FFF.FFFF = -0000_0000.7FFF_FFFF
+        // FFFF.FFFF * 7FFF.FFFF = 7FFF_FFFE.8000_0001
+        // -0000.0001 * +7FFF.FFFF = -0000_0000.7FFF_FFFF
+        let s = -I16F16::DELTA;
+        let u = U16F16::MAX >> 1u32;
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), -0x0000_0000_7FFF_FFFF);
+        assert_eq!(t.wide_mul(u).to_bits(), 0x7FFF_FFFE_8000_0001);
+        assert_eq!(s.wide_mul(v).to_bits(), -0x0000_0000_7FFF_FFFF);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+
+        // -0000.0001 * 8000.0000 = -0000_0000.8000_0000
+        // FFFF.FFFF * 8000.0000 = 7FFF_FFFF.8000_0000
+        // -0000.0001 * -8000.0000 = +0000_0000.8000_0000
+        let s = -I16F16::DELTA;
+        let u = !(U16F16::MAX >> 1u32);
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), -0x0000_0000_8000_0000);
+        assert_eq!(t.wide_mul(u).to_bits(), 0x7FFF_FFFF_8000_0000);
+        assert_eq!(s.wide_mul(v).to_bits(), 0x0000_0000_8000_0000);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+
+        // -0000.0001 * FFFF.FFFF = -0000_0000.FFFF_FFFF
+        // FFFF.FFFF * FFFF.FFFF = FFFF_FFFE.0000_0001
+        // -0000.0001 * -0000.0001 = +0000_0000.0000_0001
+        let s = -I16F16::DELTA;
+        let u = U16F16::MAX;
+        let t = U16F16::from_bits(s.to_bits() as u32);
+        let v = I16F16::from_bits(u.to_bits() as i32);
+        assert_eq!(s.wide_mul_unsigned(u).to_bits(), -0x0000_0000_FFFF_FFFF);
+        assert_eq!(t.wide_mul(u).to_bits(), 0xFFFF_FFFE_0000_0001);
+        assert_eq!(s.wide_mul(v).to_bits(), 0x0000_0000_0000_0001);
+        assert_eq!(s.wide_mul_unsigned(u), u.wide_mul_signed(s));
+        assert_eq!(t.wide_mul(u), u.wide_mul(t));
+        assert_eq!(s.wide_mul(v), v.wide_mul(s));
+    }
 }
