@@ -772,6 +772,7 @@ impl<F: Fixed> Wrapping<F> {
     /// assert_eq!(w.count_ones(), w.0.count_ones());
     /// ```
     #[inline]
+    #[doc(alias("popcount", "popcnt"))]
     pub fn count_ones(self) -> u32 {
         self.0.count_ones()
     }
@@ -1026,6 +1027,36 @@ impl<F: Fixed> Wrapping<F> {
         Wrapping(self.0.wrapping_recip())
     }
 
+    /// Returns the next multiple of `other`.
+    ///
+    /// See also
+    /// <code>FixedI32::[wrapping\_next\_multiple\_of][FixedI32::wrapping_next_multiple_of]</code>
+    /// and
+    /// <code>FixedU32::[wrapping\_next\_multiple\_of][FixedU32::wrapping_next_multiple_of]</code>.
+    ///
+    /// # Panics
+    ///
+    /// Panics if `other` is zero.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use fixed::{types::I16F16, Wrapping};
+    /// let one_point_5 = Wrapping::<I16F16>::from_num(1.5);
+    /// let four = Wrapping::<I16F16>::from_num(4);
+    /// let four_point_5 = Wrapping::<I16F16>::from_num(4.5);
+    /// assert_eq!(four.next_multiple_of(one_point_5), four_point_5);
+    ///
+    /// let max = Wrapping::<I16F16>::MAX;
+    /// let max_minus_delta = max - Wrapping::<I16F16>::DELTA;
+    /// assert_eq!(max.next_multiple_of(max_minus_delta), max_minus_delta * 2);
+    /// ```
+    #[inline]
+    #[must_use]
+    pub fn next_multiple_of(self, other: Wrapping<F>) -> Wrapping<F> {
+        Wrapping(self.0.wrapping_next_multiple_of(other.0))
+    }
+
     /// Multiply and add. Returns `self` × `mul` + `add`.
     ///
     /// See also
@@ -1344,6 +1375,60 @@ impl<F: FixedSigned> Wrapping<F> {
     pub fn signum(self) -> Wrapping<F> {
         Wrapping(self.0.wrapping_signum())
     }
+
+    /// Addition with an unsigned fixed-point number.
+    ///
+    /// See also
+    /// <code>FixedI32::[wrapping\_add\_unsigned][FixedI32::wrapping_add_unsigned]</code>.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use fixed::{
+    ///     types::{I16F16, U16F16},
+    ///     Wrapping,
+    /// };
+    /// assert_eq!(
+    ///     Wrapping::<I16F16>::from_num(-5).add_unsigned(U16F16::from_num(3)),
+    ///     Wrapping::<I16F16>::from_num(-2)
+    /// );
+    /// assert_eq!(
+    ///     Wrapping::<I16F16>::ZERO.add_unsigned(U16F16::MAX),
+    ///     -Wrapping::<I16F16>::DELTA
+    /// );
+    /// ```
+    #[inline]
+    #[must_use]
+    pub fn add_unsigned(self, rhs: F::Unsigned) -> Wrapping<F> {
+        Wrapping(self.0.wrapping_add_unsigned(rhs))
+    }
+
+    /// Subtraction with an unsigned fixed-point number.
+    ///
+    /// See also
+    /// <code>FixedI32::[wrapping\_sub\_unsigned][FixedI32::wrapping_sub_unsigned]</code>.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use fixed::{
+    ///     types::{I16F16, U16F16},
+    ///     Wrapping,
+    /// };
+    /// assert_eq!(
+    ///     Wrapping::<I16F16>::from_num(3).sub_unsigned(U16F16::from_num(5)),
+    ///     Wrapping::<I16F16>::from_num(-2)
+    /// );
+    /// assert_eq!(
+    ///     Wrapping::<I16F16>::ZERO.sub_unsigned(U16F16::MAX),
+    ///     Wrapping::<I16F16>::DELTA
+    /// );
+    /// ```
+    #[inline]
+    #[must_use]
+    pub fn sub_unsigned(self, rhs: F::Unsigned) -> Wrapping<F> {
+        Wrapping(self.0.wrapping_sub_unsigned(rhs))
+    }
 }
 
 impl<F: FixedUnsigned> Wrapping<F> {
@@ -1434,6 +1519,60 @@ impl<F: FixedUnsigned> Wrapping<F> {
     pub fn next_power_of_two(self) -> Wrapping<F> {
         Wrapping(self.0.wrapping_next_power_of_two())
     }
+
+    /// Addition with an signed fixed-point number.
+    ///
+    /// See also
+    /// <code>FixedU32::[wrapping\_add\_signed][FixedU32::wrapping_add_signed]</code>.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use fixed::{
+    ///     types::{I16F16, U16F16},
+    ///     Wrapping,
+    /// };
+    /// assert_eq!(
+    ///     Wrapping::<U16F16>::from_num(5).add_signed(I16F16::from_num(-3)),
+    ///     Wrapping::<U16F16>::from_num(2)
+    /// );
+    /// assert_eq!(
+    ///     Wrapping::<U16F16>::ZERO.add_signed(-I16F16::DELTA),
+    ///     Wrapping::<U16F16>::MAX
+    /// );
+    /// ```
+    #[inline]
+    #[must_use]
+    pub fn add_signed(self, rhs: F::Signed) -> Wrapping<F> {
+        Wrapping(self.0.wrapping_add_signed(rhs))
+    }
+
+    /// Subtraction with an signed fixed-point number.
+    ///
+    /// See also
+    /// <code>FixedU32::[wrapping\_sub\_signed][FixedU32::wrapping_sub_signed]</code>.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// use fixed::{
+    ///     types::{I16F16, U16F16},
+    ///     Wrapping,
+    /// };
+    /// assert_eq!(
+    ///     Wrapping::<U16F16>::from_num(5).sub_signed(I16F16::from_num(-3)),
+    ///     Wrapping::<U16F16>::from_num(8)
+    /// );
+    /// assert_eq!(
+    ///     Wrapping::<U16F16>::ZERO.sub_signed(I16F16::DELTA),
+    ///     Wrapping::<U16F16>::MAX
+    /// );
+    /// ```
+    #[inline]
+    #[must_use]
+    pub fn sub_signed(self, rhs: F::Signed) -> Wrapping<F> {
+        Wrapping(self.0.wrapping_sub_signed(rhs))
+    }
 }
 
 impl<F: Fixed> Display for Wrapping<F> {
@@ -1511,6 +1650,18 @@ macro_rules! op {
                 self.0 = (self.0).$wrapping(other.0);
             }
         }
+        impl<F: Fixed> $OpAssign<F> for Wrapping<F> {
+            #[inline]
+            fn $op_assign(&mut self, other: F) {
+                self.0 = (self.0).$wrapping(other);
+            }
+        }
+        impl<F: Fixed> $OpAssign<&F> for Wrapping<F> {
+            #[inline]
+            fn $op_assign(&mut self, other: &F) {
+                self.0 = (self.0).$wrapping(*other);
+            }
+        }
     };
 }
 
@@ -1574,6 +1725,24 @@ macro_rules! op_bitwise {
                 (self.0).$op_assign(&other.0);
             }
         }
+        impl<F> $OpAssign<F> for Wrapping<F>
+        where
+            F: $OpAssign<F>,
+        {
+            #[inline]
+            fn $op_assign(&mut self, other: F) {
+                (self.0).$op_assign(other);
+            }
+        }
+        impl<F> $OpAssign<&F> for Wrapping<F>
+        where
+            for<'a> F: $OpAssign<&'a F>,
+        {
+            #[inline]
+            fn $op_assign(&mut self, other: &F) {
+                (self.0).$op_assign(other);
+            }
+        }
     };
 }
 
